@@ -390,8 +390,26 @@ async def _run_batch_indexing(
 
     # Add next-step hints
     if indexed_count > 0:
+        # Check if LLM is configured for chat command
+        from mcp_vector_search.core.config_utils import (
+            get_openai_api_key,
+            get_openrouter_api_key,
+        )
+
+        config_dir = indexer.project_root / ".mcp-vector-search"
+        has_openai = get_openai_api_key(config_dir) is not None
+        has_openrouter = get_openrouter_api_key(config_dir) is not None
+        llm_configured = has_openai or has_openrouter
+
+        if llm_configured:
+            provider = "OpenAI" if has_openai else "OpenRouter"
+            chat_hint = f"[cyan]mcp-vector-search chat 'question'[/cyan] - Ask AI about your code [green](✓ {provider})[/green]"
+        else:
+            chat_hint = "[cyan]mcp-vector-search chat 'question'[/cyan] - Ask AI about your code [dim](requires API key)[/dim]"
+
         steps = [
             "[cyan]mcp-vector-search search 'your query'[/cyan] - Try semantic search",
+            chat_hint,
             "[cyan]mcp-vector-search status[/cyan] - View detailed statistics",
         ]
         print_next_steps(steps, title="Ready to Search")
@@ -567,9 +585,9 @@ async def _reindex_single_file(project_root: Path, file_path: Path) -> None:
     # Setup components
     embedding_function, cache = create_embedding_function(
         model_name=config.embedding_model,
-        cache_dir=get_default_cache_path(project_root)
-        if config.cache_embeddings
-        else None,
+        cache_dir=(
+            get_default_cache_path(project_root) if config.cache_embeddings else None
+        ),
     )
 
     database = ChromaVectorDatabase(
