@@ -259,11 +259,27 @@ class ChromaVectorDatabase(VectorDatabase):
             ids = []
 
             for chunk in chunks:
-                # Create searchable text
-                searchable_text = self._create_searchable_text(chunk)
-                documents.append(searchable_text)
+                # Debug: Check first chunk content
+                if len(documents) == 0:
+                    import sys
 
-                # Create metadata
+                    has_meta = "Language:" in chunk.content and "File:" in chunk.content
+                    print("\n[DATABASE] First chunk content check:", file=sys.stderr)
+                    print(f"  Type: {chunk.chunk_type}", file=sys.stderr)
+                    print(f"  File: {chunk.file_path.name}", file=sys.stderr)
+                    print(
+                        f"  Has metadata IN chunk.content: {has_meta}", file=sys.stderr
+                    )
+                    print(
+                        f"  Last 100 chars: {repr(chunk.content[-100:])}",
+                        file=sys.stderr,
+                    )
+
+                # Store original content directly in documents (no metadata appended)
+                # The embedding will be created from the original content
+                documents.append(chunk.content)
+
+                # Create metadata (searchable fields as metadata, not appended to content)
                 metadata = {
                     "file_path": str(chunk.file_path),
                     "start_line": chunk.start_line,
@@ -347,6 +363,7 @@ class ChromaVectorDatabase(VectorDatabase):
                     similarity = max(0.0, 1.0 / (1.0 + distance))
 
                     if similarity >= similarity_threshold:
+                        # Document contains the original content (no metadata appended)
                         result = SearchResult(
                             content=doc,
                             file_path=Path(metadata["file_path"]),
@@ -507,6 +524,7 @@ class ChromaVectorDatabase(VectorDatabase):
             if results and results.get("ids"):
                 for i, _chunk_id in enumerate(results["ids"]):
                     metadata = results["metadatas"][i]
+                    # Document now contains the original content (no metadata appended)
                     content = results["documents"][i]
 
                     # Parse JSON strings back to lists/dicts
@@ -560,6 +578,9 @@ class ChromaVectorDatabase(VectorDatabase):
 
     def _create_searchable_text(self, chunk: CodeChunk) -> str:
         """Create optimized searchable text from code chunk."""
+        import sys
+
+        print("WARNING: _create_searchable_text IS BEING CALLED!", file=sys.stderr)
         parts = [chunk.content]
 
         # Add contextual information
@@ -613,10 +634,10 @@ class ChromaVectorDatabase(VectorDatabase):
             for pickle_file in pickle_files:
                 try:
                     # Try to read the pickle file to detect corruption
-                    import pickle
+                    import pickle  # nosec B403 # Trusted internal index files only
 
                     with open(pickle_file, "rb") as f:
-                        pickle.load(f)
+                        pickle.load(f)  # nosec B301 # Trusted internal index files only
                 except (EOFError, pickle.UnpicklingError, Exception) as e:
                     logger.warning(
                         f"Corrupted index file detected: {pickle_file} - {e}"
@@ -779,6 +800,7 @@ class PooledChromaVectorDatabase(VectorDatabase):
                 ids = []
 
                 for chunk in chunks:
+                    # Store original content in documents (no metadata appended)
                     documents.append(chunk.content)
                     metadatas.append(
                         {
@@ -862,6 +884,7 @@ class PooledChromaVectorDatabase(VectorDatabase):
                         similarity = max(0.0, 1.0 / (1.0 + distance))
 
                         if similarity >= similarity_threshold:
+                            # Document contains the original content (no metadata appended)
                             result = SearchResult(
                                 content=doc,
                                 file_path=Path(metadata["file_path"]),
